Subject: bug#53210: [WIP PATCH 2/4] gnu: Rename channel-build-system and channel-source->package.

From: Josselin Poiret <[email-masked]>
Date: Mon, 14 Feb 2022 10:29:06 +0100

* etc/system-tests.scm (tests-for-current-guix):
* gnu/ci.scm (system-test-jobs):
* gnu/packages/package-management.scm (channel-source->package,
current-guix):
* guix/channels.scm (channel-build-system):
Rename channel-build-system to channel-profile-build-system and
channel-source->package to channel-source->profile-package.
---
 etc/system-tests.scm                | 2 +-
 gnu/ci.scm                          | 2 +-
 gnu/packages/package-management.scm | 4 ++--
 guix/channels.scm                   | 7 ++++---
 4 files changed, 8 insertions(+), 7 deletions(-)

diff --git a/etc/system-tests.scm b/etc/system-tests.scm
index ba0c106553..ae5e604e10 100644
--- a/etc/system-tests.scm
+++ b/etc/system-tests.scm
@@ -48,7 +48,7 @@ (define (tests-for-current-guix source commit)
   ;;
   ;;   make check-system TESTS=installed-os
   (parameterize ((current-guix-package
-                  (channel-source->package source #:commit commit)))
+                  (channel-source->profile-package source #:commit commit)))
     (match (getenv "TESTS")
       (#f
        (all-system-tests))
diff --git a/gnu/ci.scm b/gnu/ci.scm
index be19bda413..1848015194 100644
--- a/gnu/ci.scm
+++ b/gnu/ci.scm
@@ -319,7 +319,7 @@ (define (->job test)
       ;; expensive.  It also makes sure we get a valid Guix package when this
       ;; code is not running from a checkout.
       (parameterize ((current-guix-package
-                      (channel-source->package source #:commit commit)))
+                      (channel-source->profile-package source #:commit commit)))
         (map ->job (all-system-tests)))
       '()))
 
diff --git a/gnu/packages/package-management.scm b/gnu/packages/package-management.scm
index edef91ff7e..35913e6153 100644
--- a/gnu/packages/package-management.scm
+++ b/gnu/packages/package-management.scm
@@ -575,13 +575,13 @@ (define (wrong-extension? file)
     (_
      #t)))
 
-(define-public channel-source->package
+(define-public channel-source->profile-package
   (lambda* (source #:key commit)
     "Return a package for the given channel SOURCE, a lowerable object."
     (package
       (inherit guix)
       (version (string-append (package-version guix) "+"))
-      (build-system channel-build-system)
+      (build-system channel-profile-build-system)
       (arguments `(#:source ,source
                    #:commit ,commit))
       (inputs '())
diff --git a/guix/channels.scm b/guix/channels.scm
index d637d5863a..01f63d9631 100644
--- a/guix/channels.scm
+++ b/guix/channels.scm
@@ -94,7 +94,7 @@ (define-module (guix channels)
             channel-instances->derivation
             ensure-forward-channel-update
 
-            channel-build-system
+            channel-profile-build-system
 
             profile-channels
             manifest-entry-channel
@@ -955,8 +955,9 @@ (define* (latest-channel-derivation #:optional (channels %default-channels)
                                                   validate-pull)))
     (channel-instances->derivation instances)))
 
-(define channel-build-system
-  ;; Build system used to "convert" a channel instance to a package.
+(define channel-profile-build-system
+  ;; Build system used to "convert" a channel instance to a profile, in
+  ;; package form.
   (let* ((build (lambda* (name inputs
                                #:key source commit system
                                #:allow-other-keys)
-- 
2.34.0